# Generated by ariadne-codegen on 2024-03-24 07:43
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class RevokePromotionalEntitlement(BaseModel):
    revoke_promotional_entitlement: "RevokePromotionalEntitlementRevokePromotionalEntitlement" = Field(
        alias="revokePromotionalEntitlement"
    )


class RevokePromotionalEntitlementRevokePromotionalEntitlement(BaseModel):
    id: str


RevokePromotionalEntitlement.update_forward_refs()
RevokePromotionalEntitlementRevokePromotionalEntitlement.update_forward_refs()
