# Generated by ariadne-codegen on 2024-03-24 07:43
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionPreviewV2Fragment


class PreviewSubscription(BaseModel):
    preview_subscription: "PreviewSubscriptionPreviewSubscription" = Field(
        alias="previewSubscription"
    )


class PreviewSubscriptionPreviewSubscription(SubscriptionPreviewV2Fragment):
    pass


PreviewSubscription.update_forward_refs()
PreviewSubscriptionPreviewSubscription.update_forward_refs()
